@@ -1,8 +1,9 @@
-use protoc_rust::Customize;
+
 use std::fs::File;
 use std::io::Write;
 use std::path::Path;
 use std::{env, fs};
+use protobuf_codegen::Customize;
 
 fn main() {
     let out_dir = env::var("OUT_DIR").unwrap();
@@ -11,8 +12,8 @@ fn main() {
     fs::create_dir_all(&dest_path).unwrap();
 
     // Run protoc
-    protoc_rust::Codegen::new()
-        .protoc_path(protoc_bin_vendored::protoc_bin_path().unwrap())
+    protobuf_codegen::Codegen::new()
+        .pure()
         .out_dir(&dest_path.to_str().unwrap())
         .inputs(&[proto_path.join("sparkplug_b.proto").to_str().unwrap()])
         .includes(&[proto_path.to_str().unwrap()])
